==> nextcloud-30.0.11.tar.bz2: nextcloud/apps/updatenotification/l10n/ar.js <==
OC.L10N.register(
    "updatenotification",
    {
    "Channel updated" : "قناة التحديث",
    "Web updater is disabled" : "التحديث من خلال الويب معطل",
    "App updated" : "تمّ تحديث التطبيق",
    "See what's new" : "إطَّلِع على الجديد",
    "{app} updated to version {version}" : "تمّ تحديث التطبيق {app} إلى الإصدار {version}",
    "Update notifications" : "إشعارات التحديث",
    "The update server could not be reached since %d days to check for new updates." : "تعذر الوصول إلى خادم التحديث للتحقق من وجود تحديثات جديدة منذ %d أيام.",
    "Please check the Nextcloud and server log files for errors." : "يرجى التحقق من نكست كلاود و سجل أنشطة الخادم log بحثًا عن الأخطاء.",
    "Update to {serverAndVersion} is available." : "تحديث الـ {serverAndVersion} متوفّر.",
    "Update for {app} to version %s is available." : "التحديث ل {app} نسخة رقم %s متوفر.",
    "Update notification" : "إشعار التحديث",
    "Displays update notifications for Nextcloud, app updates, and provides the SSO for the updater." : "يعرض إشعارات التحديث لنكست كلاود، وتحديثات التطبيقات، و يوفر تسجيل الدخول الموحّد SSO للمُحدِّث.",
    "Give feedback" : "سجِّل انطباعك",
    "Get started" : "البدء...",
    "No changelog available" : "لا يوجد سجل بالتغييرات",
    "What's new in {app} {version}" : "ما هو الجديد في {app} {version}",
    "A new version is available: <strong>{newVersionString}</strong>" : "توجد نسخة جديدة: <strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "لاحظ أنه بعد كل إصدار جديد، لا يظهر التحديث إلا بعد الإصدار الثانوي الأول أو الأحدث. نحن نطرح إصدارات جديدة موزعة على مدار الوقت، و أحيانًا نتخطى إصدارًا عند اكتشاف مشكلات فيه. تعرّف على المزيد حول التحديثات وقنوات الإصدار على {link}",
    "Checked on {lastCheckedDate} - Open changelog" : "تمّ الفحص في {lastCheckedDate} - إفتَح سجل التغيير",
    "Checking apps for compatible versions" : "فحص التطبيقات من ناحية توافر أي إصدارات متوافقة",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "الرجاء التأكد أن ملف الconfig.php الخاص بك لا يعين قيمة <samp>appstoreenabled</samp> إلى false.",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "لم يُمكن الاتصال مع متجر التطبيقات App Store أو لم يتم إرجاع أي تحديثات. إبحث يدويّاً عن التحديثات أو تأكّد من أن الخادم الخاص بك متصل بالإنترنت و يستطيع الاتصال بالمتجر.",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong>كل </strong>التطبيقات لها نسخ متوفقة مع نسخة نكست كلاود هذه.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["<strong>%n</strong> من التطبيقات ليس لها إصدار متوافق مع إصدار نكست كلود المتاح.","<strong>%n</strong>تطبيق  ليس له إصدار متوافق مع إصدار نكست كلود المتاح.","<strong>%n</strong> من التطبيقات ليس لها إصدار متوافق مع إصدار نكست كلود المتاح.","<strong>%n</strong> من التطبيقات ليس لها إصدار متوافق مع إصدار نكست كلود المتاح.","<strong>%n</strong> من التطبيقات ليس لها إصدار متوافق مع إصدار نكست كلود المتاح.","<strong>%n</strong> من التطبيقات ليس لها إصدار متوافق مع إصدار نكست كلود المتاح."],
    "Enterprise" : "المؤسسة",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "لاستخدام المؤسسات. يوفر دائمًا أحدث مستوى من التصحيح ، ولكنه لن يتم تحديثه إلى الإصدار الرئيسي التالي على الفور. يحدث هذا التحديث بمجرد أن تقوم شركة Nextcloud GmbH بإجراء مزيد من الصلابة والاختبار لعمليات النشر واسعة النطاق والمهمة. هذه القناة متاحة فقط للعملاء وتوفر حزمة Nextcloud للمؤسسة.",
    "Stable" : "مستقر",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "أحدث نسخة مستقرة.  مناسبه للاستخدام المنتظم وسيتم تحديثه دائمًا إلى أحدث إصدار رئيسي.",
    "Beta" : "تجريبي",
    "A pre-release version only for testing new features, not for production environments." : "نسخة تجريبية فقط لاختبار الميزات الجديدة ، وليس لبيئات الإنتاجية.",
    "Update" : "تحديث",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "لم يعد الإصدار الذي تقوم بتشغيله قيد الصيانة. يرجى التأكد من التحديث إلى إصدار مدعوم في أقرب وقت ممكن.",
    "Apps missing compatible version" : "تفتقد التطبيقات إلى إصدار متوافق",
    "View in store" : "العرض على المتجر",
    "Apps with compatible version" : "تطبيقات بإصدار متوافق",
    "Please note that the web updater is not recommended with more than 100 accounts! Please use the command line updater instead!" : "يرجى ملاحظة أنه لا يوصى باستخدام أداة تحديث الويب مع أكثر من 100 حساب! الرجاء استخدام الأمر السطري للتحديث command line updater بدلاً من ذلك!",
    "Open updater" : "فتح المحدِّث",
    "Download now" : "حمل الآن",
    "Web updater is disabled. Please use the command line updater or the appropriate update mechanism for your installation method (e.g. Docker pull) to update." : "مُحدِّث الوِب Web updater تمّ تعطيله. رجاءً، استعمل للتحديث الأمر السطري updater أو آلية تحديث مناسبة لطريقتك في التثبيت (مثل Docker pull).",
    "What's new?" : "مالجديد؟",
    "View changelog" : "اعرض سجل التغييرات",
    "The update check is not yet finished. Please refresh the page." : "التحقق من التحديث لم ينته بعد. يرجى تحديث الصفحة.",
    "Your version is up to date." : "النسخة لديك هي الأحدث.",
    "A non-default update server is in use to be checked for updates:" : "يتم استخدام خادم تحديث غير افتراضي للتحقق من وجود تحديثات:",
    "Update channel" : "قناة التحديث",
    "Changing the update channel also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "يؤثر تغيير قناة التحديث أيضًا على صفحة إدارة التطبيقات. على سبيل المثال بعد التبديل إلى القناة التجريبية، سيتم تقديم تحديثات التطبيق التجريبي لك في صفحة إدارة التطبيقات.",
    "Current update channel:" : "قناة التحديث الحالية:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "يمكنك دائمًا التحديث إلى إصدار أحدث. لكن لا يمكنك الرجوع إلى إصدار أكثر استقرارًا.",
    "Notify members of the following groups about available updates:" : "إشعار أعضاء المجموعات التالية بتوفر التحديثات:",
    "No groups" : "لا توجد مجموعات",
    "Only notifications for app updates are available." : "توجد فقط إشعارات حول تحديثات التطبيقات",
    "The selected update channel makes dedicated notifications for the server obsolete." : "قناة التحديث المحددة تجعل الإشعارات المخصصة للخادم قديمة.",
    "The selected update channel does not support updates of the server." : "قناة التحديث المحددة لا تدعم تحديثات الخادم.",
    "Changelog for app {app}" : "سجل التغييرات للتطبيق {app}",
    "What's new in {app} version {version}" : "ما الجديد في الإصدار {version} من التطبيق {app}",
    "{version} is available. Get more information on how to update." : "الإصدار {version} متوفر. أحصُل على معلومات عن كيفية التحديث."
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> nextcloud-31.0.9.tar.bz2: nextcloud/apps/updatenotification/l10n/ar.js <==
OC.L10N.register(
    "updatenotification",
    {
    "Channel updated" : "قناة التحديث",
    "Web updater is disabled" : "التحديث من خلال الويب معطل",
    "App updated" : "تمّ تحديث التطبيق",
    "See what's new" : "إطَّلِع على الجديد",
    "{app} updated to version {version}" : "تمّ تحديث التطبيق {app} إلى الإصدار {version}",
    "Update notifications" : "إشعارات التحديث",
    "The update server could not be reached since %d days to check for new updates." : "تعذر الوصول إلى خادم التحديث للتحقق من وجود تحديثات جديدة منذ %d أيام.",
    "Please check the Nextcloud and server log files for errors." : "يرجى التحقق من نكست كلاود و سجل أنشطة الخادم log بحثًا عن الأخطاء.",
    "Update to {serverAndVersion} is available." : "تحديث الـ {serverAndVersion} متوفّر.",
    "Update for {app} to version %s is available." : "التحديث ل {app} نسخة رقم %s متوفر.",
    "Update notification" : "إشعار التحديث",
    "Displays update notifications for Nextcloud, app updates, and provides the SSO for the updater." : "يعرض إشعارات التحديث لنكست كلاود، وتحديثات التطبيقات، و يوفر تسجيل الدخول الموحّد SSO للمُحدِّث.",
    "Give feedback" : "سجِّل انطباعك",
    "Get started" : "البدء...",
    "No changelog available" : "لا يوجد سجل بالتغييرات",
    "What's new in {app} {version}" : "ما هو الجديد في {app} {version}",
    "A new version is available: <strong>{newVersionString}</strong>" : "توجد نسخة جديدة: <strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "لاحظ أنه بعد كل إصدار جديد، لا يظهر التحديث إلا بعد الإصدار الثانوي الأول أو الأحدث. نحن نطرح إصدارات جديدة موزعة على مدار الوقت، و أحيانًا نتخطى إصدارًا عند اكتشاف مشكلات فيه. تعرّف على المزيد حول التحديثات وقنوات الإصدار على {link}",
    "Checked on {lastCheckedDate} - Open changelog" : "تمّ الفحص في {lastCheckedDate} - إفتَح سجل التغيير",
    "Checking apps for compatible versions" : "فحص التطبيقات من ناحية توافر أي إصدارات متوافقة",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "الرجاء التأكد أن ملف الconfig.php الخاص بك لا يعين قيمة <samp>appstoreenabled</samp> إلى false.",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "لم يُمكن الاتصال مع متجر التطبيقات App Store أو لم يتم إرجاع أي تحديثات. إبحث يدويّاً عن التحديثات أو تأكّد من أن الخادم الخاص بك متصل بالإنترنت و يستطيع الاتصال بالمتجر.",
    "Enterprise" : "المؤسسة",
    "Stable" : "مستقر",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "أحدث نسخة مستقرة.  مناسبه للاستخدام المنتظم وسيتم تحديثه دائمًا إلى أحدث إصدار رئيسي.",
    "Beta" : "تجريبي",
    "A pre-release version only for testing new features, not for production environments." : "نسخة تجريبية فقط لاختبار الميزات الجديدة ، وليس لبيئات الإنتاجية.",
    "Update" : "تحديث",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "لم يعد الإصدار الذي تقوم بتشغيله قيد الصيانة. يرجى التأكد من التحديث إلى إصدار مدعوم في أقرب وقت ممكن.",
    "Apps missing compatible version" : "تفتقد التطبيقات إلى إصدار متوافق",
    "View in store" : "العرض على المتجر",
    "Apps with compatible version" : "تطبيقات بإصدار متوافق",
    "Please note that the web updater is not recommended with more than 100 accounts! Please use the command line updater instead!" : "يرجى ملاحظة أنه لا يوصى باستخدام أداة تحديث الويب مع أكثر من 100 حساب! الرجاء استخدام الأمر السطري للتحديث command line updater بدلاً من ذلك!",
    "Open updater" : "فتح المحدِّث",
    "Download now" : "حمل الآن",
    "Web updater is disabled. Please use the command line updater or the appropriate update mechanism for your installation method (e.g. Docker pull) to update." : "مُحدِّث الوِب Web updater تمّ تعطيله. رجاءً، استعمل للتحديث الأمر السطري updater أو آلية تحديث مناسبة لطريقتك في التثبيت (مثل Docker pull).",
    "What's new?" : "مالجديد؟",
    "View changelog" : "اعرض سجل التغييرات",
    "The update check is not yet finished. Please refresh the page." : "التحقق من التحديث لم ينته بعد. يرجى تحديث الصفحة.",
    "Your version is up to date." : "النسخة لديك هي الأحدث.",
    "A non-default update server is in use to be checked for updates:" : "يتم استخدام خادم تحديث غير افتراضي للتحقق من وجود تحديثات:",
    "Update channel" : "قناة التحديث",
    "Changing the update channel also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "يؤثر تغيير قناة التحديث أيضًا على صفحة إدارة التطبيقات. على سبيل المثال بعد التبديل إلى القناة التجريبية، سيتم تقديم تحديثات التطبيق التجريبي لك في صفحة إدارة التطبيقات.",
    "Current update channel:" : "قناة التحديث الحالية:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "يمكنك دائمًا التحديث إلى إصدار أحدث. لكن لا يمكنك الرجوع إلى إصدار أكثر استقرارًا.",
    "Notify members of the following groups about available updates:" : "إشعار أعضاء المجموعات التالية بتوفر التحديثات:",
    "No groups" : "لا توجد مجموعات",
    "Only notifications for app updates are available." : "توجد فقط إشعارات حول تحديثات التطبيقات",
    "The selected update channel makes dedicated notifications for the server obsolete." : "قناة التحديث المحددة تجعل الإشعارات المخصصة للخادم قديمة.",
    "The selected update channel does not support updates of the server." : "قناة التحديث المحددة لا تدعم تحديثات الخادم.",
    "Changelog for app {app}" : "سجل التغييرات للتطبيق {app}",
    "What's new in {app} version {version}" : "ما الجديد في الإصدار {version} من التطبيق {app}",
    "{version} is available. Get more information on how to update." : "الإصدار {version} متوفر. أحصُل على معلومات عن كيفية التحديث.",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong>كل </strong>التطبيقات لها نسخ متوفقة مع نسخة نكست كلاود هذه.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["<strong>%n</strong> من التطبيقات ليس لها إصدار متوافق مع إصدار نكست كلود المتاح.","<strong>%n</strong>تطبيق  ليس له إصدار متوافق مع إصدار نكست كلود المتاح.","<strong>%n</strong> من التطبيقات ليس لها إصدار متوافق مع إصدار نكست كلود المتاح.","<strong>%n</strong> من التطبيقات ليس لها إصدار متوافق مع إصدار نكست كلود المتاح.","<strong>%n</strong> من التطبيقات ليس لها إصدار متوافق مع إصدار نكست كلود المتاح.","<strong>%n</strong> من التطبيقات ليس لها إصدار متوافق مع إصدار نكست كلود المتاح."],
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "لاستخدام المؤسسات. يوفر دائمًا أحدث مستوى من التصحيح ، ولكنه لن يتم تحديثه إلى الإصدار الرئيسي التالي على الفور. يحدث هذا التحديث بمجرد أن تقوم شركة Nextcloud GmbH بإجراء مزيد من الصلابة والاختبار لعمليات النشر واسعة النطاق والمهمة. هذه القناة متاحة فقط للعملاء وتوفر حزمة Nextcloud للمؤسسة."
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
